mbed Connector Interface simplification API on top of mbed-client

Fork of mbedConnectorInterfaceV3 by Doug Anson

NOTE:

This repo has been replaced with https://github.com/ARMmbed/mbedConnectorInterface. No further updates will occur with this repo. Please use the github repo instead. Thanks!

Revision:
46:62da4ce20276
Parent:
44:7c73baf9f4c1
Child:
54:dfee8691c83a
--- a/mbed-connector-interface/ConnectorEndpoint.h	Wed Jun 15 20:51:13 2016 +0000
+++ b/mbed-connector-interface/ConnectorEndpoint.h	Wed Jun 15 22:40:29 2016 +0000
@@ -71,7 +71,7 @@
     /**
     Build out the endpoint.
     */
-    void build_endpoint();
+    void buildEndpoint();
 
     /**
     Plumb the lower RF network stack
@@ -124,11 +124,14 @@
 	// get our Options
 	Options *getOptions();
 	
-	// get our Server
-	M2MSecurity *getServer();
+	// get our Endpoint Interface
+	M2MInterface *getEndpointInterface();
 	
-	// get our Object List
-	M2MObjectList  getObjectList();
+	// get our Endpoint Security
+	M2MSecurity *getEndpointSecurity();
+	
+	// get our Endpoint Object List
+	M2MObjectList  getEndpointObjectList();
 	
 	// configure to act as router node
 	void asRouterNode(bool canActAsRouterNode);
@@ -171,10 +174,9 @@
     bool			   			 m_registered;
     
     // mbed-client support
-    M2MInterface      			*m_interface;
-    M2MSecurity       			*m_server_instance;
-    M2MObjectList      			 m_object_list;
-    M2MDevice         			*m_device_object;
+    M2MInterface      			*m_endpoint_interface;
+    M2MSecurity       			*m_endpoint_security;
+    M2MObjectList      			 m_endpoint_object_list;
     
     // Device Manager
     void			  			*m_device_manager;
@@ -186,8 +188,8 @@
 	ObjectInstanceManager		*m_oim;
 	
 	// mbed-client methods
-    void 			 create_interface();
-    M2MSecurity 	*create_server_instance();
+    void 			 createEndpointInterface();
+    M2MSecurity 	*createEndpointInstance();
     
 	// DynamicResource Lookup
 	DynamicResource *lookupDynamicResource(M2MBase *base);